# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyxiver']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.26.0,<3.0.0', 'xmltodict>=0.12.0,<0.13.0']

setup_kwargs = {
    'name': 'pyxiver',
    'version': '1.0.3',
    'description': 'Python wrapper for the arXiv.org public API.',
    'long_description': '# pyXiver\n\n\n**pyXiver** (pyCHIver) is a wrapper for the arXiv public API.\n\nThank you to arXiv for use of its open access interoperability.\n\n*This project is NOT connected to arXiv (arxiv.org) and Cornell University.*\n\n### Install\n```python\npip install pyxiver\n```\n\n### Example\n\n```python\nimport pyxiver\nimport pprint\n\nprinter = pprint.PrettyPrinter()\n\n# Provide query - all params are optional except for the search string (e.g. "black hole")\nquery = pyxiver.get_all(\'black hole\',\n                        search_field="ti",\n                        max_results=2,\n                        sort_by=\'submittedDate\',\n                        sort_order=\'descending\')\n\n# Verbose content - multiple papers\nverbose_content = query.verbose\nprinter.pprint(verbose_content)\n\n# Minimal content - provides only the title, summary, id, and category\nminimal_content = query.minimal\nprinter.pprint(minimal_content)\n\n\n# Provide the abstract URL found as the "id" key from the list of articles fetched through get_all()\nquery_one = pyxiver.get_one(\'http://arxiv.org/abs/2106.05901v1\')\n\n# Verbose content - single paper\nverbose_content = query_one.verbose\nprinter.pprint(verbose_content)\n\n# Minimal content - provides only the title, authors, published date, and summary\nminimal_content = query_one.minimal\nprinter.pprint(minimal_content)\n```\n\n## Query Params\n\n### Get multiple papers\n\n- **query**: Query string to search arXiv\n\n- **search_field**: Search fields listed below\n\n| Prefix  | Explanation |\n| ------- | ----------- |\n| ti  | title  |\n| au  | author  |\n| all | all fields (default) |\n\n*For more fields, please visit https://arxiv.org/help/api/user-manual#query_details*\n\n- **max_results**: Count of articles to be returned (default is 10)\n\n- **sort_by**: Sort by "relevance", "lastUpdatedDate", "submittedDate" (default is relevance)\n\n- **sort_order**: Order by "ascending" or "descending" (default is descending)\n\n### Example response for multiple papers\n```\nVERBOSE\n\n[{\'arxiv:comment\': {\'#text\': \'Submitted to MNRAS. 30 pages, 26 figures. \'\n                             \'Trinity code available at:\\n\'\n                             \'  https://github.com/HaowenZhang/TRINITY \'\n                             \'Comments welcome!\',\n                    \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n  \'arxiv:primary_category\': {\'@scheme\': \'http://arxiv.org/schemas/atom\',\n                             \'@term\': \'astro-ph.GA\',\n                             \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n  \'author\': [{\'name\': \'Haowen Zhang\'},\n             {\'name\': \'Peter Behroozi\'},\n             {\'name\': \'Marta Volonteri\'},\n             {\'name\': \'Joseph Silk\'},\n             {\'name\': \'Xiaohui Fan\'},\n             {\'name\': \'Philip F. Hopkins\'},\n             {\'name\': \'Jinyi Yang\'},\n             {\'name\': \'James Aird\'}],\n  \'category\': {\'@scheme\': \'http://arxiv.org/schemas/atom\',\n               \'@term\': \'astro-ph.GA\'},\n  \'id\': \'http://arxiv.org/abs/2105.10474v1\',\n  \'link\': [{\'@href\': \'http://arxiv.org/abs/2105.10474v1\',\n            \'@rel\': \'alternate\',\n            \'@type\': \'text/html\'},\n           {\'@href\': \'http://arxiv.org/pdf/2105.10474v1\',\n            \'@rel\': \'related\',\n            \'@title\': \'pdf\',\n            \'@type\': \'application/pdf\'}],\n  \'published\': \'2021-05-21T17:26:51Z\',\n  \'summary\': \'We present Trinity, a flexible empirical model that \'\n             \'self-consistently infers\\n\'\n             \'the statistical connection between dark matter haloes, galaxies, \'\n             \'and\\n\'\n             \'supermassive black holes (SMBHs). Trinity is constrained by \'\n             \'galaxy observables\\n\'\n             "from $0 < z < 10$ (galaxies\' stellar mass functions, specific "\n             \'and cosmic SFRs,\\n\'\n             \'quenched fractions, and UV luminosity functions) and SMBH \'\n             \'observables from $0 <\\n\'\n             \'z < 6.5$ (quasar luminosity functions, quasar probability \'\n             \'distribution\\n\'\n             \'functions, active black hole mass functions, local SMBH \'\n             \'mass-bulge mass\\n\'\n             \'relations, and the observed SMBH mass distributions of high \'\n             \'redshift bright\\n\'\n             \'quasars). The model includes full treatment of observational \'\n             \'systematics (e.g.,\\n\'\n             \'AGN obscuration and errors in stellar masses). From these data, \'\n             \'Trinity infers\\n\'\n             \'the average SMBH mass, SMBH accretion rate, merger rate, and \'\n             \'Eddington ratio\\n\'\n             \'distribution as functions of halo mass, galaxy stellar mass, and \'\n             \'redshift. Key\\n\'\n             \'findings include: 1) the normalization of the SMBH mass-bulge \'\n             \'mass relation\\n\'\n             \'increases only mildly from $z=0$ to $z=3$, but decreases more \'\n             \'strongly from\\n\'\n             \'$z=3$ to $z=10$; 2) The AGN radiative$+$kinetic efficiency is \'\n             \'$\\\\sim$0.04-0.07,\\n\'\n             \'and does not show significant redshift dependence given the \'\n             \'existing data\\n\'\n             \'constraints; 3) AGNs show downsizing, i.e., the Eddington ratios \'\n             \'of more\\n\'\n             \'massive SMBHs start to decrease earlier than those of lower-mass \'\n             \'objects; 4)\\n\'\n             \'The average ratio between average SMBH accretion rate and SFR is \'\n             \'$\\\\sim10^{-3}$\\n\'\n             \'for low-mass galaxies, which are primarily star-forming. This \'\n             \'ratio increases\\n\'\n             \'to $\\\\sim10^{-1}$ for the most massive haloes below $z\\\\sim1$, \'\n             \'where star\\n\'\n             \'formation is quenched but SMBHs continue to accrete.\',\n  \'title\': \'Trinity I: Self-Consistently Modeling the Dark Matter\\n\'\n           \'  Halo-Galaxy-Supermassive Black Hole Connection from $z=0-10$\',\n  \'updated\': \'2021-05-21T17:26:51Z\'},\n {\'arxiv:comment\': {\'#text\': \'PhD thesis, The University of Edinburgh, 195 \'\n                             \'pages, 2 figures.\\n\'\n                             \'  Includes: integrated discussion of colour \'\n                             \'states and impulse observables; new\\n\'\n                             \'  discussion of wavefunctions; new results for \'\n                             \'radiation kernels for\\n\'\n                             \'  Reissner-Nordstr\\\\"{o}m black holes; \'\n                             \'corrections of minor typos from published\\n\'\n                             \'  papers\',\n                    \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n  \'arxiv:primary_category\': {\'@scheme\': \'http://arxiv.org/schemas/atom\',\n                             \'@term\': \'hep-th\',\n                             \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n  \'author\': {\'name\': \'Ben Maybee\'},\n  \'category\': [{\'@scheme\': \'http://arxiv.org/schemas/atom\', \'@term\': \'hep-th\'},\n               {\'@scheme\': \'http://arxiv.org/schemas/atom\', \'@term\': \'gr-qc\'}],\n  \'id\': \'http://arxiv.org/abs/2105.10268v1\',\n  \'link\': [{\'@href\': \'http://arxiv.org/abs/2105.10268v1\',\n            \'@rel\': \'alternate\',\n            \'@type\': \'text/html\'},\n           {\'@href\': \'http://arxiv.org/pdf/2105.10268v1\',\n            \'@rel\': \'related\',\n            \'@title\': \'pdf\',\n            \'@type\': \'application/pdf\'}],\n  \'published\': \'2021-05-21T10:39:18Z\',\n  \'summary\': \'On-shell scattering amplitudes have proven to be useful tools \'\n             \'for tackling\\n\'\n             \'the two-body problem in general relativity. This thesis outlines \'\n             \'how to compute\\n\'\n             \'relevant classical observables that are themselves on-shell, \'\n             \'directly from\\n\'\n             \'amplitudes; examples considered are the momentum impulse, total \'\n             \'radiated\\n\'\n             \'momentum, and angular impulse for spinning particles. As \'\n             \'applications we derive\\n\'\n             \'results relevant for black hole physics, computing in the \'\n             \'post-Minkowskian\\n\'\n             \'expansion of GR, and construct a worldsheet effective action for \'\n             \'the leading\\n\'\n             \'spin interactions of Kerr black holes.\',\n  \'title\': \'On-Shell Physics of Black Holes\',\n  \'updated\': \'2021-05-21T10:39:18Z\'}]\n\n***************************************************************************************************\n\nMINIMAL  \n\n[{\'category\': \'astro-ph.GA\',\n  \'id\': \'http://arxiv.org/abs/2105.10474v1\',\n  \'summary\': \'We present Trinity, a flexible empirical model that \'\n             \'self-consistently infers\\n\'\n             \'the statistical connection between dark matter haloes, galaxies, \'\n             \'and\\n\'\n             \'supermassive black holes (SMBHs). Trinity is constrained by \'\n             \'galaxy observables\\n\'\n             "from $0 < z < 10$ (galaxies\' stellar mass functions, specific "\n             \'and cosmic SFRs,\\n\'\n             \'quenched fractions, and UV luminosity functions) and SMBH \'\n             \'observables from $0 <\\n\'\n             \'z < 6.5$ (quasar luminosity functions, quasar probability \'\n             \'distribution\\n\'\n             \'functions, active black hole mass functions, local SMBH \'\n             \'mass-bulge mass\\n\'\n             \'relations, and the observed SMBH mass distributions of high \'\n             \'redshift bright\\n\'\n             \'quasars). The model includes full treatment of observational \'\n             \'systematics (e.g.,\\n\'\n             \'AGN obscuration and errors in stellar masses). From these data, \'\n             \'Trinity infers\\n\'\n             \'the average SMBH mass, SMBH accretion rate, merger rate, and \'\n             \'Eddington ratio\\n\'\n             \'distribution as functions of halo mass, galaxy stellar mass, and \'\n             \'redshift. Key\\n\'\n             \'findings include: 1) the normalization of the SMBH mass-bulge \'\n             \'mass relation\\n\'\n             \'increases only mildly from $z=0$ to $z=3$, but decreases more \'\n             \'strongly from\\n\'\n             \'$z=3$ to $z=10$; 2) The AGN radiative$+$kinetic efficiency is \'\n             \'$\\\\sim$0.04-0.07,\\n\'\n             \'and does not show significant redshift dependence given the \'\n             \'existing data\\n\'\n             \'constraints; 3) AGNs show downsizing, i.e., the Eddington ratios \'\n             \'of more\\n\'\n             \'massive SMBHs start to decrease earlier than those of lower-mass \'\n             \'objects; 4)\\n\'\n             \'The average ratio between average SMBH accretion rate and SFR is \'\n             \'$\\\\sim10^{-3}$\\n\'\n             \'for low-mass galaxies, which are primarily star-forming. This \'\n             \'ratio increases\\n\'\n             \'to $\\\\sim10^{-1}$ for the most massive haloes below $z\\\\sim1$, \'\n             \'where star\\n\'\n             \'formation is quenched but SMBHs continue to accrete.\',\n  \'title\': \'Trinity I: Self-Consistently Modeling the Dark Matter\\n\'\n           \'  Halo-Galaxy-Supermassive Black Hole Connection from $z=0-10$\'},\n {\'category\': \'hep-th\',\n  \'id\': \'http://arxiv.org/abs/2105.10268v1\',\n  \'summary\': \'On-shell scattering amplitudes have proven to be useful tools \'\n             \'for tackling\\n\'\n             \'the two-body problem in general relativity. This thesis outlines \'\n             \'how to compute\\n\'\n             \'relevant classical observables that are themselves on-shell, \'\n             \'directly from\\n\'\n             \'amplitudes; examples considered are the momentum impulse, total \'\n             \'radiated\\n\'\n             \'momentum, and angular impulse for spinning particles. As \'\n             \'applications we derive\\n\'\n             \'results relevant for black hole physics, computing in the \'\n             \'post-Minkowskian\\n\'\n             \'expansion of GR, and construct a worldsheet effective action for \'\n             \'the leading\\n\'\n             \'spin interactions of Kerr black holes.\',\n  \'title\': \'On-Shell Physics of Black Holes\'}]\n\n```\n\n### Get a single paper\n\n- **arxiv_url**: this is the abstract URL of the paper. This can be found as the \'id\' key of a paper from the list of \npapers fetched using the pyxiver.get_all() method.\n  \n### Example response for a single paper\n```\nVERBOSE\n\n{\'arxiv:comment\': {\'#text\': \'15 pages, 4 figures, one appendix. Comments are \'\n                            \'welcome\',\n                   \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n \'arxiv:primary_category\': {\'@scheme\': \'http://arxiv.org/schemas/atom\',\n                            \'@term\': \'hep-ph\',\n                            \'@xmlns:arxiv\': \'http://arxiv.org/schemas/atom\'},\n \'author\': [{\'name\': \'Guan-Wen Yuan\'},\n            {\'name\': \'Zhan-Fang Chen\'},\n            {\'name\': \'Zhao-Qiang Shen\'},\n            {\'name\': \'Wen-Qing Guo\'},\n            {\'name\': \'Ran Ding\'},\n            {\'name\': \'Xiaoyuan Huang\'},\n            {\'name\': \'Qiang Yuan\'}],\n \'category\': [{\'@scheme\': \'http://arxiv.org/schemas/atom\', \'@term\': \'hep-ph\'},\n              {\'@scheme\': \'http://arxiv.org/schemas/atom\',\n               \'@term\': \'astro-ph.HE\'}],\n \'id\': \'http://arxiv.org/abs/2106.05901v1\',\n \'link\': [{\'@href\': \'http://arxiv.org/abs/2106.05901v1\',\n           \'@rel\': \'alternate\',\n           \'@type\': \'text/html\'},\n          {\'@href\': \'http://arxiv.org/pdf/2106.05901v1\',\n           \'@rel\': \'related\',\n           \'@title\': \'pdf\',\n           \'@type\': \'application/pdf\'}],\n \'published\': \'2021-06-10T16:29:25Z\',\n \'summary\': \'The fast developments of radio astronomy open a new window to \'\n            \'explore the\\n\'\n            \'properties of Dark Matter (DM). The recent direct imaging of the \'\n            \'supermassive\\n\'\n            \'black hole (SMBH) at the center of M87 radio galaxy by the Event \'\n            \'Horizon\\n\'\n            \'Telescope (EHT) collaboration is expected to be very useful to \'\n            \'search for\\n\'\n            \'possible new physics. In this work, we illustrate that such \'\n            \'results can be used\\n\'\n            \'to detect the possible synchrotron radiation signature produced \'\n            \'by DM\\n\'\n            \'annihilation from the innermost region of the SMBH. Assuming the \'\n            \'existence of a\\n\'\n            \'spiky DM density profile, we obtain the flux density due to DM \'\n            \'annihilation\\n\'\n            \'induced electrons and positrons, and derive new limits on the DM \'\n            \'annihilation\\n\'\n            \'cross section via the comparison with the EHT integral flux \'\n            \'density at 230 GHz.\\n\'\n            \'Our results show that the parameter space can be probed by the \'\n            \'EHT observations\\n\'\n            \'is largely complementary to other experiments. For DM with \'\n            \'typical mass regions\\n\'\n            \'of being weakly interacting massive particles, the annihilation \'\n            \'cross section\\n\'\n            \'several orders of magnitude below the thermal production level \'\n            \'can be excluded\\n\'\n            \'by the EHT observations under the density spike assumption. \'\n            \'Future EHT\\n\'\n            \'observations may further improve the sensitivity on the DM \'\n            \'searches, and may\\n\'\n            \'also provide a unique opportunity to test the interplay between \'\n            \'DM and the\\n\'\n            \'SMBH.\',\n \'title\': \'Strong Limits on Dark Matter Annihilation from the Event Horizon\\n\'\n          \'  Telescope Observations of M87$^\\\\star$\',\n \'updated\': \'2021-06-10T16:29:25Z\'}\n \n ***************************************************************************************************\n \n MINIMAL\n \n {\'author\': [{\'name\': \'Guan-Wen Yuan\'},\n            {\'name\': \'Zhan-Fang Chen\'},\n            {\'name\': \'Zhao-Qiang Shen\'},\n            {\'name\': \'Wen-Qing Guo\'},\n            {\'name\': \'Ran Ding\'},\n            {\'name\': \'Xiaoyuan Huang\'},\n            {\'name\': \'Qiang Yuan\'}],\n \'published\': \'2021-06-10T16:29:25Z\',\n \'summary\': \'The fast developments of radio astronomy open a new window to \'\n            \'explore the\\n\'\n            \'properties of Dark Matter (DM). The recent direct imaging of the \'\n            \'supermassive\\n\'\n            \'black hole (SMBH) at the center of M87 radio galaxy by the Event \'\n            \'Horizon\\n\'\n            \'Telescope (EHT) collaboration is expected to be very useful to \'\n            \'search for\\n\'\n            \'possible new physics. In this work, we illustrate that such \'\n            \'results can be used\\n\'\n            \'to detect the possible synchrotron radiation signature produced \'\n            \'by DM\\n\'\n            \'annihilation from the innermost region of the SMBH. Assuming the \'\n            \'existence of a\\n\'\n            \'spiky DM density profile, we obtain the flux density due to DM \'\n            \'annihilation\\n\'\n            \'induced electrons and positrons, and derive new limits on the DM \'\n            \'annihilation\\n\'\n            \'cross section via the comparison with the EHT integral flux \'\n            \'density at 230 GHz.\\n\'\n            \'Our results show that the parameter space can be probed by the \'\n            \'EHT observations\\n\'\n            \'is largely complementary to other experiments. For DM with \'\n            \'typical mass regions\\n\'\n            \'of being weakly interacting massive particles, the annihilation \'\n            \'cross section\\n\'\n            \'several orders of magnitude below the thermal production level \'\n            \'can be excluded\\n\'\n            \'by the EHT observations under the density spike assumption. \'\n            \'Future EHT\\n\'\n            \'observations may further improve the sensitivity on the DM \'\n            \'searches, and may\\n\'\n            \'also provide a unique opportunity to test the interplay between \'\n            \'DM and the\\n\'\n            \'SMBH.\',\n \'title\': \'Strong Limits on Dark Matter Annihilation from the Event Horizon\\n\'\n          \'  Telescope Observations of M87$^\\\\star$\'}\n```\n\n## Development\n\nThe project uses poetry to package and manage dependencies:\n\n```commandline\npoetry install\n```\n\nRun tests:\n\n```commandline\npoetry run pytest\n```\n\n\n## License\n\nMIT License\n\nCopyright (c) 2021 Neil Van\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n',
    'author': 'Neil Van',
    'author_email': 'nvq.alino@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
